@@ -23,7 +23,6 @@
 
 #include "config.h"
 
-#include <glade/glade.h>
 #include "zenity.h"
 #include "util.h"
 
@@ -43,26 +42,32 @@ zenity_entry_fill_entries (GSList **entries, const gchar **args)
   }
 }
 
+static void
+zenity_entry_combo_activate_default (GtkEntry *entry, gpointer window)
+{
+  gtk_window_activate_default (GTK_WINDOW (window));
+}
+
 void 
 zenity_entry (ZenityData *data, ZenityEntryData *entry_data)
 {
-  GladeXML *glade_dialog = NULL;
+  GtkBuilder *builder = NULL;
   GtkWidget *dialog;
-  GtkWidget *text;
+  GObject *text;
   GSList *entries = NULL; 
   GSList *tmp;
-  GtkWidget *vbox;
+  GObject *vbox;
   
-  glade_dialog = zenity_util_load_glade_file ("zenity_entry_dialog");
+  builder = zenity_util_load_ui_file ("zenity_entry_dialog", NULL);
 
-  if (glade_dialog == NULL) {
+  if (builder == NULL) {
     data->exit_code = zenity_util_return_exit_code (ZENITY_ERROR);
     return;
   }
 	
-  glade_xml_signal_autoconnect (glade_dialog);
+  gtk_builder_connect_signals (builder, NULL);
 	
-  dialog = glade_xml_get_widget (glade_dialog, "zenity_entry_dialog");
+  dialog = GTK_WIDGET (gtk_builder_get_object (builder, "zenity_entry_dialog"));
 	
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (zenity_entry_dialog_response), data);
@@ -75,28 +80,32 @@ zenity_entry (ZenityData *data, ZenityEntryData *entry_data)
   if (data->width > -1 || data->height > -1)
     gtk_window_set_default_size (GTK_WINDOW (dialog), data->width, data->height);
 
-  text = glade_xml_get_widget (glade_dialog, "zenity_entry_text");
+  text = gtk_builder_get_object (builder, "zenity_entry_text");
 
   if (entry_data->dialog_text)
-    gtk_label_set_text_with_mnemonic (GTK_LABEL (text), entry_data->dialog_text);
+    gtk_label_set_text_with_mnemonic (GTK_LABEL (text), g_strcompress (entry_data->dialog_text));
   
-  vbox = glade_xml_get_widget (glade_dialog, "vbox4");
+  vbox = gtk_builder_get_object (builder, "vbox4");
   
   zenity_entry_fill_entries(&entries, entry_data->data);
   
   n_entries = g_slist_length (entries);
 
   if (n_entries > 1) {
-    entry = gtk_combo_box_entry_new_text ();
+    entry = gtk_combo_box_new_with_entry ();
 
     for (tmp = entries; tmp; tmp = tmp->next) {
-      gtk_combo_box_append_text (GTK_COMBO_BOX (entry), tmp->data);
+      gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (entry), tmp->data);
     }
 
     if (entry_data->entry_text) {
-      gtk_combo_box_prepend_text (GTK_COMBO_BOX (entry), entry_data->entry_text);
+      gtk_combo_box_text_prepend_text (GTK_COMBO_BOX_TEXT (entry), entry_data->entry_text);
       gtk_combo_box_set_active (GTK_COMBO_BOX (entry), 0);
     }
+
+    g_signal_connect (gtk_bin_get_child (GTK_BIN (entry)), "activate",
+                      G_CALLBACK (zenity_entry_combo_activate_default),
+                      GTK_WINDOW (dialog));
   } else {
     entry = gtk_entry_new();
 
@@ -113,15 +122,14 @@ zenity_entry (ZenityData *data, ZenityEntryData *entry_data)
 
   gtk_box_pack_end (GTK_BOX (vbox), entry, FALSE, FALSE, 0);
 
-  if (glade_dialog)
-    g_object_unref (glade_dialog);
-
   gtk_label_set_mnemonic_widget (GTK_LABEL (text), entry);
 
+  g_object_unref (builder);
+
   zenity_util_show_dialog (dialog);
 
   if(data->timeout_delay > 0) {
-    g_timeout_add (data->timeout_delay * 1000, (GSourceFunc) zenity_util_timeout_handle, NULL);
+    g_timeout_add_seconds (data->timeout_delay, (GSourceFunc) zenity_util_timeout_handle, NULL);
   }
 
   gtk_main ();
@@ -137,7 +145,7 @@ zenity_entry_dialog_response (GtkWidget *widget, int response, gpointer data)
     case GTK_RESPONSE_OK:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
       if (n_entries > 1) {
-        text = gtk_combo_box_get_active_text (GTK_COMBO_BOX (entry));
+	text = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (entry));
       }
       else {
         text = gtk_entry_get_text (GTK_ENTRY (entry));      
